#ifndef NT2_INCLUDE_CONSTANTS_SQRT_2OPI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRT_2OPI_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/sqrt_2opi.hpp>

#endif
